enum PgSqlMergeActionKind: string

Enumerates the row actions supported by MERGE simulation.

Cases

case Update = 'UPDATE'
case Insert = 'INSERT'
case Delete = 'DELETE'
case DoNothing = 'DO NOTHING'

Test cases 19

Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.

Dedicated tests 1
Other tests reaching this symbol 18

Relations

Constant reads 8
Type declarations 1