enum PgSqlMergeMatchKind: string

Enumerates the target and source matching modes of a MERGE branch.

Cases

case Matched = 'MATCHED'
case NotMatched = 'NOT MATCHED'

Test cases 16

Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.

Dedicated tests 1
Other tests reaching this symbol 15

Relations

Constant reads 8
Type declarations 2