enumPgSqlMergeMatchKind
enum PgSqlMergeMatchKind: string
Enumerates the target and source matching modes of a MERGE branch.
Cases
case Matched = 'MATCHED'case NotMatched = 'NOT MATCHED'Test cases 16
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 1
Other tests reaching this symbol 15
PgSqlSessionFactoryTestcallsPgSqlRewriterTestcallsStatementRewriterTestcallsMatchConditionsTestcallsRowActionsTestcallsMergeTransformerTestcallsPgSqlTransformerTestcallsRowMutationResolverTestcallsPgSqlMutationResolverTestcallsActionClauseTest::testActionMatchesTheBranchKindcallsActionClauseTest::testParseClausecallsPgSqlMergeClauseTest::testCarriesTypedClauseDatacallsPgSqlMergeParserTest::testParsesMatchedUpdateAndNotMatchedInsertcallsPgSqlMergeStatementTest::testCarriesTypedStatementDatacallsStatementPartsTestcalls
Relations
Constant reads 8
- class-const ZtdQuery\Platform\Postgres\Rewrite\Transformer\Merge\MatchConditions::effectiveConditions() packages/ztd-query-postgres/src/Rewrite/Transformer/Merge/MatchConditions.php:26
- class-const ZtdQuery\Platform\Postgres\Rewrite\Transformer\Merge\MatchConditions::effectiveConditions() packages/ztd-query-postgres/src/Rewrite/Transformer/Merge/MatchConditions.php:39
- class-const ZtdQuery\Platform\Postgres\Rewrite\Transformer\Merge\RowActions::unchangedRows() packages/ztd-query-postgres/src/Rewrite/Transformer/Merge/RowActions.php:56
- class-const ZtdQuery\Platform\Postgres\Sql\Merge\ActionClause::parseClause() packages/ztd-query-postgres/src/Sql/Merge/ActionClause.php:28
- class-const ZtdQuery\Platform\Postgres\Sql\Merge\ActionClause::parseClause() packages/ztd-query-postgres/src/Sql/Merge/ActionClause.php:31
- class-const ZtdQuery\Platform\Postgres\Sql\Merge\ActionClause::action() packages/ztd-query-postgres/src/Sql/Merge/ActionClause.php:220
- class-const ZtdQuery\Platform\Postgres\Sql\Merge\ActionClause::action() packages/ztd-query-postgres/src/Sql/Merge/ActionClause.php:223
- class-const ZtdQuery\Platform\Postgres\Sql\Merge\ActionClause::action() packages/ztd-query-postgres/src/Sql/Merge/ActionClause.php:231